iconv-hook ASCII 646
iconv-hook ISO-8859-15 ISO8859-15
iconv-hook ISO-8859-1 ISO8859-1
iconv-hook ISO-8859-2 ISO8859-2
iconv-hook ISO-8859-4 ISO8859-4
iconv-hook ISO-8859-5 ISO8859-5
iconv-hook ISO-8859-6 ISO8859-6
iconv-hook ISO-8859-7 ISO8859-7
iconv-hook ISO-8859-8 ISO8859-8
iconv-hook ISO-8859-9 ISO8859-9
iconv-hook KOI8-R koi8-r
iconv-hook TIS-620 TIS620.2533
